using System;
using System.IO;
using System.Net;
using System.Threading;
using System.Xml.Linq;

namespace Microsoft.SmallBasic.Library.Internal
{
	/// <summary>
	/// A private static helper for calling Rest based APIs
	/// </summary>
	internal sealed class RestHelper
	{
		/// <summary>
		/// Given a Rest URL, gets the contents as an XML Document.
		/// </summary>
		internal static XDocument GetContents(string url)
		{
			XDocument result = null;
			try
			{
				WebRequest webRequest = WebRequest.Create(url);
				ManualResetEvent evt = new ManualResetEvent(initialState: false);
				IAsyncResult asyncResult = webRequest.BeginGetResponse(delegate
				{
					evt.Set();
				}, null);
				evt.WaitOne();
				using (WebResponse webResponse = webRequest.EndGetResponse(asyncResult))
				{
					using (Stream stream = webResponse.GetResponseStream())
					{
						string text = new StreamReader(stream).ReadToEnd();
						result = XDocument.Parse(text);
						return result;
					}
				}
			}
			catch (Exception)
			{
				return result;
			}
		}
	}
}
