using System;
using System.Globalization;

namespace Microsoft.SmallBasic.Library
{
	/// <summary>
	/// This class provides access to the system clock
	/// </summary>
	[SmallBasicType]
	public sealed class Clock
	{
		/// <summary>
		/// Gets the current system time.
		/// </summary>
		public static Primitive Time
		{
			get
			{
				DateTimeFormatInfo instance = DateTimeFormatInfo.GetInstance(CultureInfo.CurrentCulture);
				return DateTime.Now.ToString(instance.LongTimePattern, CultureInfo.CurrentUICulture);
			}
		}

		/// <summary>
		/// Gets the current system date.
		/// </summary>
		public static Primitive Date
		{
			get
			{
				DateTimeFormatInfo instance = DateTimeFormatInfo.GetInstance(CultureInfo.CurrentCulture);
				return DateTime.Now.ToString(instance.ShortDatePattern, CultureInfo.CurrentUICulture);
			}
		}

		/// <summary>
		/// Gets the current year.
		/// </summary>
		public static Primitive Year => DateTime.Now.Year;

		/// <summary>
		/// Gets the current Month.
		/// </summary>
		public static Primitive Month => DateTime.Now.Month;

		/// <summary>
		/// Gets the current day of the month.
		/// </summary>
		public static Primitive Day => DateTime.Now.Day;

		/// <summary>
		/// Gets the current day of the week.
		/// </summary>
		public static Primitive WeekDay => DateTime.Now.ToString("dddd", CultureInfo.CurrentUICulture);

		/// <summary>
		/// Gets the current Hour.
		/// </summary>
		public static Primitive Hour => DateTime.Now.Hour;

		/// <summary>
		/// Gets the current Minute.
		/// </summary>
		public static Primitive Minute => DateTime.Now.Minute;

		/// <summary>
		/// Gets the current Second.
		/// </summary>
		public static Primitive Second => DateTime.Now.Second;

		/// <summary>
		/// Gets the current Millisecond.
		/// </summary>
		public static Primitive Millisecond => DateTime.Now.Millisecond;

		/// <summary>
		/// Gets the number of milliseconds that have elapsed since 1900.
		/// </summary>
		public static Primitive ElapsedMilliseconds => (DateTime.Now - new DateTime(1900, 1, 1)).TotalMilliseconds;
	}
}
