using System.IO;
using System.Windows;
using System.Windows.Media.Imaging;
using Microsoft.SmallBasic.Library.Internal;

namespace Microsoft.SmallBasic.Library
{
	/// <summary>
	/// This class provides methods to interact with the desktop.
	/// </summary>
	[SmallBasicType]
	public sealed class Desktop
	{
		/// <summary>
		/// Gets the screen width of the primary desktop.
		/// </summary>
		public static Primitive Width => SystemParameters.PrimaryScreenWidth;

		/// <summary>
		/// Gets the screen height of the primary desktop.
		/// </summary>
		public static Primitive Height => SystemParameters.PrimaryScreenHeight;

		/// <summary>
		/// Sets the specified picture as the desktop's wallpaper.  This file could be a local file or a network file or even an Internet URL.
		/// </summary>
		/// <param name="fileOrUrl">
		/// The filename or URL of the picture.
		/// </param>
		public static void SetWallPaper(Primitive fileOrUrl)
		{
			if (!fileOrUrl.IsEmpty)
			{
				string lpvParam = ConvertToBitmap(fileOrUrl);
				NativeHelper.SystemParametersInfo(20, 0, lpvParam, 3);
			}
		}

		internal static Primitive ConvertToBitmap(Primitive fileNameOrUrl)
		{
			if (fileNameOrUrl.IsEmpty)
			{
				return fileNameOrUrl;
			}
			string localFile = Path.GetTempFileName();
			SmallBasicApplication.Invoke(delegate
			{
				BitmapImage bitmapImage = ImageList.LoadImageFromFile(fileNameOrUrl);
				if (bitmapImage != null)
				{
					BmpBitmapEncoder bmpBitmapEncoder = new BmpBitmapEncoder();
					BitmapFrame item = BitmapFrame.Create(bitmapImage);
					bmpBitmapEncoder.Frames.Add(item);
					using (Stream stream = System.IO.File.Create(localFile))
					{
						bmpBitmapEncoder.Save(stream);
					}
				}
			});
			return new Primitive(localFile);
		}
	}
}
