using System;
using System.IO;
using System.Text;
using System.Xml;
using Microsoft.SmallBasic.Library.Internal;

namespace Microsoft.SmallBasic.Library
{
	/// <summary>
	/// This class provides access to an online Dictionary service.
	/// </summary>
	[SmallBasicType]
	public sealed class Dictionary
	{
		private const string _queryXml = "<QueryPacket xmlns='urn:Microsoft.Search.Query' revision='1' >\r\n                                   <Query domain='{2}'>\r\n                                     <Context>\r\n                                       <QueryText type='STRING' language='en-us' >{0}</QueryText>\r\n                                       <LanguagePreference>en-us</LanguagePreference>\r\n                                     </Context>\r\n                                     <OfficeContext xmlns='urn:Microsoft.Search.Query.Office.Context' revision='1'>\r\n                                       <UserPreferences>\r\n                                         <ParentalControl>false</ParentalControl>\r\n                                       </UserPreferences>\r\n                                       <ServiceData>{1}</ServiceData>\r\n                                       <ApplicationContext>\r\n                                         <Name>Microsoft Office Word</Name>\r\n                                         <Version>(14.0.3524)</Version>\r\n                                       </ApplicationContext>\r\n                                       <QueryLanguage>en-us</QueryLanguage>\r\n                                       <KeyboardLanguage>en-us</KeyboardLanguage>\r\n                                    </OfficeContext>\r\n                                   </Query>\r\n                                 </QueryPacket>";

		/// <summary>
		/// Gets the definition of a word in English.  The same as GetDefinitionEnglishToEnglish.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinition(Primitive word)
		{
			return GetDefinitionEnglishToEnglish(word);
		}

		/// <summary>
		/// Gets the definition of a word, English to English.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionEnglishToEnglish(Primitive word)
		{
			return GetDefinition(word, "EDICT", "{FEF89077-4F4D-4803-A8BF-228083F70EAA}");
		}

		/// <summary>
		/// Gets the definition of a word, Simplified Chinese to English.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionSimplifiedChineseToEnglish(Primitive word)
		{
			return GetDefinition(word, "2052/1033/4", "{03D4CECF-0578-4DBF-BDEB-F55502662B51}");
		}

		/// <summary>
		/// Gets the definition of a word, English to German.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionEnglishToGerman(Primitive word)
		{
			return GetDefinition(word, "1033/1031/4", "0FDEA0C3-A12B-4BD8-983E-96BBAE93B097");
		}

		/// <summary>
		/// Gets the definition of a word, English to Simplified Chinese.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionEnglishToSimplifiedChinese(Primitive word)
		{
			return GetDefinition(word, "1033/2052/4", "{2D4205BC-1D59-43B4-9156-19F8B8AEF1A4}");
		}

		/// <summary>
		/// Gets the definition of a word, English to French.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionEnglishToFrench(Primitive word)
		{
			return GetDefinition(word, "1033/1036/4", "{30C1B7BD-93FF-44A6-928F-D848AEE0BDD6}");
		}

		/// <summary>
		/// Gets the definition of a word, German to English.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionGermanToEnglish(Primitive word)
		{
			return GetDefinition(word, "1031/1033/4", "{63D351DB-D12E-448B-8541-9F794E1EC973}");
		}

		/// <summary>
		/// Gets the definition of a word, English to Japanese.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionEnglishToJapanese(Primitive word)
		{
			return GetDefinition(word, "1033/1041/4", "{871E52A8-6A33-4753-B3D3-A1A6A723BC9F}");
		}

		/// <summary>
		/// Gets the definition of a word, French to English.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionFrenchToEnglish(Primitive word)
		{
			return GetDefinition(word, "1036/1033/4", "{FE5F4005-127F-4885-8366-68CF00CED317}");
		}

		/// <summary>
		/// Gets the definition of a word, Itlian to English.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionItalianToEnglish(Primitive word)
		{
			return GetDefinition(word, "1040/1033/4", "{A7F03864-B9E3-4824-9E30-D0BD52AE37DF}");
		}

		/// <summary>
		/// Gets the definition of a word, Traditional Chinese to English.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionTraditionalChineseToEnglish(Primitive word)
		{
			return GetDefinition(word, "1028/1033/4", "{9FC92720-10A4-47FE-8066-E7567FBA0AB4}");
		}

		/// <summary>
		/// Gets the definition of a word, Spanish to English.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionSpanishToEnglish(Primitive word)
		{
			return GetDefinition(word, "3082/1033/4", "{B7B7DDE2-AFFB-415B-BB77-BC1A0D4D694D}");
		}

		/// <summary>
		/// Gets the definition of a word, Japanese to English.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionJapaneseToEnglish(Primitive word)
		{
			return GetDefinition(word, "1041/1033/4", "{C6032F4A-557E-4FC0-AFA8-46B918B626EB}");
		}

		/// <summary>
		/// Gets the definition of a word, English to Korean.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionEnglishToKorean(Primitive word)
		{
			return GetDefinition(word, "1033/1042/4", "{CF56F86E-4DBE-42BF-BB08-1C9BBF2B26F2}");
		}

		/// <summary>
		/// Gets the definition of a word, English to Traditional Chinese.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionEnglishToTraditionalChinese(Primitive word)
		{
			return GetDefinition(word, "1033/1028/4", "{F08B2224-AAA5-42E9-B668-A448BFC16D5B}");
		}

		/// <summary>
		/// Gets the definition of a word, Korean to English.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionKoreanToEnglish(Primitive word)
		{
			return GetDefinition(word, "1042/1033/4", "{F1A3E34D-7A0A-4118-84F2-17D2CAB58F18}");
		}

		/// <summary>
		/// Gets the definition of a word, English to Italian.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionEnglishToItalian(Primitive word)
		{
			return GetDefinition(word, "1033/1040/4", "{F8EB68DA-29AF-4CE1-B188-3D5384A7259A}");
		}

		/// <summary>
		/// Gets the definition of a word, English to Spanish.
		/// </summary>
		/// <param name="word">
		/// The word to define.
		/// </param>
		/// <returns>
		/// The definition(s) of the specified word.
		/// </returns>
		public static Primitive GetDefinitionEnglishToSpanish(Primitive word)
		{
			return GetDefinition(word, "1033/3082/4", "{FE0FEFA5-ED3B-4D8E-AC1A-A308A9210C34}");
		}

		private static string GetDefinition(string word, string serviceCode, string langGuid)
		{
			StringBuilder stringBuilder = new StringBuilder();
			try
			{
				OfficeResearch officeResearch = new OfficeResearch();
				string s = officeResearch.Query(string.Format("<QueryPacket xmlns='urn:Microsoft.Search.Query' revision='1' >\r\n                                   <Query domain='{2}'>\r\n                                     <Context>\r\n                                       <QueryText type='STRING' language='en-us' >{0}</QueryText>\r\n                                       <LanguagePreference>en-us</LanguagePreference>\r\n                                     </Context>\r\n                                     <OfficeContext xmlns='urn:Microsoft.Search.Query.Office.Context' revision='1'>\r\n                                       <UserPreferences>\r\n                                         <ParentalControl>false</ParentalControl>\r\n                                       </UserPreferences>\r\n                                       <ServiceData>{1}</ServiceData>\r\n                                       <ApplicationContext>\r\n                                         <Name>Microsoft Office Word</Name>\r\n                                         <Version>(14.0.3524)</Version>\r\n                                       </ApplicationContext>\r\n                                       <QueryLanguage>en-us</QueryLanguage>\r\n                                       <KeyboardLanguage>en-us</KeyboardLanguage>\r\n                                    </OfficeContext>\r\n                                   </Query>\r\n                                 </QueryPacket>", word, serviceCode, langGuid));
				XmlTextReader xmlTextReader = new XmlTextReader(new StringReader(s));
				xmlTextReader.WhitespaceHandling = WhitespaceHandling.Significant;
				if (xmlTextReader.ReadToDescendant("Content"))
				{
					XmlReader xmlReader = xmlTextReader.ReadSubtree();
					while (xmlReader.Read())
					{
						switch (xmlReader.Name)
						{
						case "Heading":
						case "Line":
						case "P":
							stringBuilder.AppendLine();
							break;
						case "Char":
						case "Text":
							if (xmlReader.NodeType == XmlNodeType.Element)
							{
								stringBuilder.Append(" ");
							}
							break;
						default:
							if (xmlReader.NodeType == XmlNodeType.Text)
							{
								stringBuilder.Append(xmlReader.Value);
							}
							break;
						}
					}
				}
			}
			catch (Exception)
			{
			}
			return stringBuilder.ToString();
		}
	}
}
