using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Xml.Linq;
using Microsoft.SmallBasic.Library.Internal;

namespace Microsoft.SmallBasic.Library
{
	/// <summary>
	/// This class provides access to Flickr photo services.
	/// </summary>
	[SmallBasicType]
	public sealed class Flickr
	{
		private const string _apiKey = "MWY5ZmI5ODE4Mjk2NzAwNTgwYmYzMzQwMjc5MzQ2YjY=";

		/// <summary>
		/// Flickr URL Template (with https)
		/// </summary>
		private static string _urlTemplate;

		private static string _picUrlTemplate;

		private static string _cachedTag;

		private static XDocument _cachedTagDocument;

		private static int _cachedTagDocumentHitCount;

		static Flickr()
		{
			_urlTemplate = "https://api.flickr.com/services/rest/?sort=interestingness-desc&safe_search=1&license=1,2,3,4,5,6,7&api_key=";
			_picUrlTemplate = "http://farm{0}.static.flickr.com/{1}/{2}_{3}.jpg";
			byte[] array = Convert.FromBase64String("MWY5ZmI5ODE4Mjk2NzAwNTgwYmYzMzQwMjc5MzQ2YjY=");
			_urlTemplate += Encoding.UTF8.GetString(array, 0, array.Length);
		}

		/// <summary>
		/// Gets the URL for the picture of the moment.
		/// </summary>
		/// <returns>
		/// A file URL for Flickr's picture of the moment
		/// </returns>
		public static Primitive GetPictureOfMoment()
		{
			Random random = new Random((int)DateTime.Now.Ticks);
			string url = $"{_urlTemplate}&method=flickr.photos.getRecent&per_page=50&page={random.Next(10) + 1}";
			Thread.Sleep(1000);
			return GetRandomPhotoNodeUrl(RestHelper.GetContents(url));
		}

		/// <summary>
		/// Gets the URL for a random picture tagged with the specified tag.
		/// </summary>
		/// <param name="tag">
		/// The tag for the requested picture.
		/// </param>
		/// <returns>
		/// A file URL for Flickr's random picture
		/// </returns>
		public static Primitive GetRandomPicture(Primitive tag)
		{
			Random random = new Random((int)DateTime.Now.Ticks);
			if ((bool)(tag == _cachedTag && (Primitive)(_cachedTagDocument != null) && (Primitive)(_cachedTagDocumentHitCount < 10)))
			{
				_cachedTagDocumentHitCount++;
				return GetRandomPhotoNodeUrl(_cachedTagDocument);
			}
			string url = $"{_urlTemplate}&method=flickr.photos.search&per_page=50&tags={tag}&page={random.Next(10) + 1}";
			Thread.Sleep(1000);
			_cachedTag = tag;
			_cachedTagDocument = RestHelper.GetContents(url);
			_cachedTagDocumentHitCount = 0;
			return GetRandomPhotoNodeUrl(_cachedTagDocument);
		}

		private static string GetRandomPhotoNodeUrl(XDocument document)
		{
			if (document == null)
			{
				return "";
			}
			try
			{
				IEnumerable<XElement> source = document.Descendants("photo");
				Random random = new Random((int)DateTime.Now.Ticks);
				XElement xElement = source.ElementAt(random.Next(source.Count()));
				string value = xElement.Attribute("id").Value;
				string value2 = xElement.Attribute("secret").Value;
				string value3 = xElement.Attribute("server").Value;
				string value4 = xElement.Attribute("farm").Value;
				return string.Format(_picUrlTemplate, value4, value3, value, value2);
			}
			catch
			{
			}
			return "";
		}
	}
}
