using System.Drawing;
using System.Windows.Forms;
using System.Windows.Input;

namespace Microsoft.SmallBasic.Library
{
	/// <summary>
	/// The mouse class provides accessors to get or set the mouse related properties, like the cursor position, pointer, etc.
	/// </summary>
	[SmallBasicType]
	public sealed class Mouse
	{
		/// <summary>
		/// Gets or sets the mouse cursor's x co-ordinate.
		/// </summary>
		public static Primitive MouseX
		{
			get
			{
				return new Primitive(System.Windows.Forms.Cursor.Position.X);
			}
			set
			{
				System.Windows.Forms.Cursor.Position = new Point(value, MouseY);
			}
		}

		/// <summary>
		/// Gets or sets the mouse cursor's y co-ordinate.
		/// </summary>
		public static Primitive MouseY
		{
			get
			{
				return new Primitive(System.Windows.Forms.Cursor.Position.Y);
			}
			set
			{
				System.Windows.Forms.Cursor.Position = new Point(MouseX, value);
			}
		}

		/// <summary>
		/// Gets whether or not the left button is pressed.
		/// </summary>
		public static Primitive IsLeftButtonDown => new Primitive((Control.MouseButtons & MouseButtons.Left) == MouseButtons.Left);

		/// <summary>
		/// Gets whether or not the right button is pressed.
		/// </summary>
		public static Primitive IsRightButtonDown => new Primitive((Control.MouseButtons & MouseButtons.Right) == MouseButtons.Right);

		/// <summary>
		/// Hides the mouse cursor on the screen.
		/// </summary>
		public static void HideCursor()
		{
			GraphicsWindow.SetCursor(System.Windows.Input.Cursors.None);
		}

		/// <summary>
		/// Shows the mouse cursors on the screen.
		/// </summary>
		public static void ShowCursor()
		{
			GraphicsWindow.SetCursor(System.Windows.Input.Cursors.Arrow);
		}
	}
}
