using System;
using System.Collections.Generic;
using System.Reflection;

namespace Microsoft.SmallBasic.Library
{
	/// <summary>
	/// The Platform object provides a way to generically invoke other .Net libraries.
	/// </summary>
	public sealed class Platform
	{
		private static Dictionary<string, int> _nameGenerationMap = new Dictionary<string, int>();

		private static Dictionary<string, object> _objectMap = new Dictionary<string, object>();

		public static Primitive CreateInstance(Primitive typeName)
		{
			try
			{
				Type type = Type.GetType(typeName);
				object value = Activator.CreateInstance(type);
				string text = GenerateNewName("Instance");
				_objectMap[text] = value;
				return text;
			}
			catch
			{
				return "ERROR";
			}
		}

		public static Primitive InvokeInstanceMethod(Primitive instanceId, Primitive methodName, Primitive argumentsStackName)
		{
			try
			{
				object obj = _objectMap[instanceId];
				MethodInfo method = obj.GetType().GetMethod(methodName, BindingFlags.IgnoreCase | BindingFlags.Instance | BindingFlags.Public);
				int num = Stack.GetCount(argumentsStackName);
				ParameterInfo[] parameters = method.GetParameters();
				if (parameters.Length == num)
				{
					List<object> list = new List<object>();
					for (int num2 = num - 1; num2 >= 0; num2--)
					{
						list[num2] = Stack.PopValue(argumentsStackName);
					}
					return new Primitive(method.Invoke(obj, list.ToArray()));
				}
				return "ERROR";
			}
			catch
			{
				return "ERROR";
			}
		}

		public static Primitive InvokeStaticMethod(Primitive typeName, Primitive methodName, Primitive argumentsStackName)
		{
			try
			{
				Type type = Type.GetType(typeName);
				MethodInfo method = type.GetMethod(methodName, BindingFlags.IgnoreCase | BindingFlags.Static | BindingFlags.Public);
				int num = Stack.GetCount(argumentsStackName);
				ParameterInfo[] parameters = method.GetParameters();
				if (parameters.Length == num)
				{
					List<object> list = new List<object>();
					for (int num2 = num - 1; num2 >= 0; num2--)
					{
						list[num2] = Stack.PopValue(argumentsStackName);
					}
					return new Primitive(method.Invoke(null, list.ToArray()));
				}
				return "ERROR";
			}
			catch
			{
				return "ERROR";
			}
		}

		internal static string GenerateNewName(string prefix)
		{
			int value = 0;
			_nameGenerationMap.TryGetValue(prefix, out value);
			value++;
			_nameGenerationMap[prefix] = value;
			return prefix + value;
		}
	}
}
