using System;
using System.IO;
using System.Reflection;
using System.Threading;
using Microsoft.SmallBasic.Library.Internal;

namespace Microsoft.SmallBasic.Library
{
	/// <summary>
	/// The Program class provides helpers to control the program execution.
	/// </summary>
	[SmallBasicType]
	public sealed class Program
	{
		private static string[] args = Environment.GetCommandLineArgs();

		/// <summary>
		/// Gets the number of command-line arguments passed to this program.
		/// </summary>
		public static Primitive ArgumentCount => (args.Length != 0) ? (args.Length - 1) : 0;

		/// <summary>
		/// Gets the executing program's directory.
		/// </summary>
		public static Primitive Directory
		{
			get
			{
				Assembly entryAssembly = Assembly.GetEntryAssembly();
				return Path.GetDirectoryName(entryAssembly.Location);
			}
		}

		/// <summary>
		/// Delays program execution by the specified amount of MilliSeconds.
		/// </summary>
		/// <param name="milliSeconds">
		/// The amount of delay.
		/// </param>
		public static void Delay(Primitive milliSeconds)
		{
			Thread.Sleep(TimeSpan.FromMilliseconds(milliSeconds));
		}

		/// <summary>
		/// Ends the program.
		/// </summary>
		public static void End()
		{
			SmallBasicApplication.End();
		}

		/// <summary>
		/// Returns the specified argument passed to this program.
		/// </summary>
		/// <param name="index">
		/// Index of the argument.
		/// </param>
		/// <returns>
		/// The command-line argument at the specified index.
		/// </returns>
		public static Primitive GetArgument(Primitive index)
		{
			int num = index;
			if (num >= 1 && num < args.Length)
			{
				return new Primitive(args[num]);
			}
			return new Primitive("");
		}
	}
}
