using System.Collections.Generic;

namespace Microsoft.SmallBasic.Library
{
	/// <summary>
	/// This object provides a way of storing values just like stacking up a plate.  You can push a value to the top of the stack and pop it off. You can only pop the values one by one off the stack and the last pushed value will be the first one to pop out.
	/// </summary>
	[SmallBasicType]
	public sealed class Stack
	{
		private static Dictionary<Primitive, Stack<Primitive>> _stackMap = new Dictionary<Primitive, Stack<Primitive>>();

		/// <summary>
		/// Pushes a value to the specified stack.
		/// </summary>
		/// <param name="stackName">
		/// The name of the stack.
		/// </param>
		/// <param name="value">
		/// The value to push.
		/// </param>
		public static void PushValue(Primitive stackName, Primitive value)
		{
			if (!_stackMap.TryGetValue(stackName, out var value2))
			{
				value2 = new Stack<Primitive>();
				_stackMap[stackName] = value2;
			}
			value2.Push(value);
		}

		/// <summary>
		/// Gets the count of items in the specified stack.
		/// </summary>
		/// <param name="stackName">
		/// The name of the stack.
		/// </param>
		/// <returns>
		/// The number of items in the specified stack.
		/// </returns>
		public static Primitive GetCount(Primitive stackName)
		{
			if (!_stackMap.TryGetValue(stackName, out var value))
			{
				value = new Stack<Primitive>();
				_stackMap[stackName] = value;
			}
			return value.Count;
		}

		/// <summary>
		/// Pops the value from the specified stack.
		/// </summary>
		/// <param name="stackName">
		/// The name of the stack.
		/// </param>
		/// <returns>
		/// The value from the stack.
		/// </returns>
		public static Primitive PopValue(Primitive stackName)
		{
			if (_stackMap.TryGetValue(stackName, out var value))
			{
				return value.Pop();
			}
			return "";
		}
	}
}
